Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(223)

Unified Diff: chrome/common/safe_browsing/csd.proto

Issue 2072933002: Add sampling of unknown filetypes in download protection. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Add int values for histograms to ensure they match Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_tests_unit.gypi ('k') | chrome/common/safe_browsing/file_type_policies.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/safe_browsing/csd.proto
diff --git a/chrome/common/safe_browsing/csd.proto b/chrome/common/safe_browsing/csd.proto
index 66e14f449d655c89b336c103926f5474ddf282ae..01214f167c67eab8e610fbb7f088f661bfb199bd 100644
--- a/chrome/common/safe_browsing/csd.proto
+++ b/chrome/common/safe_browsing/csd.proto
@@ -286,9 +286,12 @@ message ClientDownloadRequest {
// A .dmg, .pkg, etc, that Chrome failed to unpack to the point of finding
// Mach O's.
INVALID_MAC_ARCHIVE = 8;
- PPAPI_SAVE_REQUEST =
- 9; // A download request initiated via PPAPI. Typically
- // the requestor is a Flash applet.
+ // A download request initiated via PPAPI. Typically the requestor is
+ // a Flash applet.
+ PPAPI_SAVE_REQUEST = 9;
+ // A file we don't support, but we've decided to sample and send
+ // a light-ping.
+ SAMPLED_UNSUPPORTED_FILE = 10;
}
optional DownloadType download_type = 10 [default = WIN_EXECUTABLE];
« no previous file with comments | « chrome/chrome_tests_unit.gypi ('k') | chrome/common/safe_browsing/file_type_policies.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698